OpenWISP Notifications
======================

.. image:: https://github.com/openwisp/openwisp-notifications/workflows/OpenWISP%20CI%20Build/badge.svg?branch=master
    :target: https://github.com/openwisp/openwisp-notifications/actions?query=workflow%3A%22OpenWISP+CI+Build%22
    :alt: CI build status

.. image:: https://coveralls.io/repos/github/openwisp/openwisp-notifications/badge.svg?branch=master
    :target: https://coveralls.io/github/openwisp/openwisp-notifications?branch=master
    :alt: Test Coverage

.. image:: https://img.shields.io/librariesio/github/openwisp/openwisp-notifications
    :target: https://libraries.io/github/openwisp/openwisp-notifications#repository_dependencies
    :alt: Dependency monitoring

.. image:: https://img.shields.io/gitter/room/nwjs/nw.js.svg
    :target: https://gitter.im/openwisp/general
    :alt: chat

.. image:: https://badge.fury.io/py/openwisp-notifications.svg
    :target: http://badge.fury.io/py/openwisp-notifications
    :alt: Pypi Version

.. image:: https://pepy.tech/badge/openwisp-notifications
    :target: https://pepy.tech/project/openwisp-notifications
    :alt: downloads

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
    :target: https://pypi.org/project/black/
    :alt: code style: black

----

.. figure:: https://github.com/openwisp/openwisp-notifications/raw/docs/docs/images/notification-demo.gif
    :align: center

**OpenWISP Notifications** provides email and web notifications for
`OpenWISP <http://openwisp.org>`_.

Its main goal is to allow the other OpenWISP modules to notify users about
meaningful events that happen in their network.

For a complete overview of features, refer to the `Notifications: Features
<https://openwisp.io/docs/dev/notifications/user/intro.html>`_ section of
the OpenWISP documentation.

Documentation
-------------

- `Usage documentation <https://openwisp.io/docs/dev/notifications/>`_
- `Developer documentation
  <https://openwisp.io/docs/dev/notifications/developer/>`_

----

Contributing
------------

Please read the `OpenWISP contributing guidelines
<http://openwisp.io/docs/developer/contributing.html>`_.

License
-------

See `LICENSE
<https://github.com/openwisp/openwisp-notifications/blob/master/LICENSE>`_.

Support
-------

See `OpenWISP Support Channels <http://openwisp.org/support.html>`_.

Attributions
------------

Icons
~~~~~

`Icons
<https://github.com/openwisp/openwisp-notifications/tree/master/openwisp_notifications/static/openwisp-notifications/images/icons/>`_
used are taken from `Font Awesome <https://fontawesome.com/>`_ project.

LICENSE: https://fontawesome.com/license

Sound
~~~~~

`Notification sound
<https://github.com/openwisp/openwisp-notifications/tree/master/openwisp_notifications/static/openwisp-notifications/audio>`_
is taken from `Notification Sounds <https://notificationsounds.com/>`_.

LICENSE: `Creative Commons Attribution license
<https://creativecommons.org/licenses/by/4.0/legalcode>`_
